@@ -19,7 +19,6 @@ logger = logging.getLogger("datatorch.agent.action")
 
 
 async def get_action(config: ActionConfig, step: "Step" = None) -> Action:
-
     # Get actions directory
     action_dir = agent_directory.action_dir(config.name, config.version)
     folder_exists = os.path.exists(action_dir)
@@ -30,9 +29,7 @@ async def get_action(config: ActionConfig, step: "Step" = None) -> Action:
             "Action found locally ({}@{}).".format(config.name, config.version)
         )
     else:
-        logger.debug(
-            "Downloading action {}@{}.".format(config.name, config.version)
-        )
+        logger.debug("Downloading action {}@{}.".format(config.name, config.version))
         await config.download()
 
     return Action(config, action_dir, step=step)
