@@ -1,4 +1,6 @@
 from typing import List, Union, cast, IO
+import requests, glob, os, cgi
+from urllib.parse import urlencode
 
 from gql import Client as GqlClient, gql
 from gql.transport.transport import Transport
@@ -131,7 +133,6 @@ class Client(object):
         return self.to_class(Entity, results, path=path)
 
     def to_class(self, Entity, results: Union[dict, list, None], path: str = ""):
-
         for key in path.split("."):
             results = results.get(key)  # type: ignore
 
@@ -142,3 +143,41 @@ class Client(object):
             return list(map(lambda e: Entity(e, self), results))
 
         return Entity(results, self)
+
+    def download_file(
+        self,
+        id: str,
+        name: str = "",
+        directory: str = "./",
+        skip: bool = True
+        # For now, skip does nothing
+    ):
+        # If it exists and skip is true, do not download
+        name = os.path.join(directory, name)
+        name = os.path.abspath(name)
+
+        if os.path.isfile(name) & skip == True:
+            return name, None
+
+        query_string = urlencode({"download": "true", "stream": "true"})
+        url = normalize_api_url(self.api_url)
+        download_url = f"{url}/file/v1/{id}/{name}?{query_string}"
+
+        result = requests.get(
+            download_url, headers={self.token_header: self._api_token}, stream=True
+        )
+
+        content = result.headers["content-disposition"]
+        _, value = cgi.parse_header(content)
+
+        name = name or value["filename"]
+        name = os.path.join(directory, name)
+        name = os.path.abspath(name)
+
+        os.makedirs(os.path.dirname(name), exist_ok=True)
+
+        with open(name, "wb") as f:
+            for chunk in result.iter_content(1024):
+                f.write(chunk)
+
+        return name, result
